@@ -30,7 +30,10 @@ import import_declare_test
 from trackme_libs_logging import setup_logger
 
 logger = setup_logger("trackme.rest.ack", "trackme_rest_api_ack.log")
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -224,7 +227,7 @@ class TrackMeHandlerAck_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -517,7 +520,7 @@ class TrackMeHandlerAck_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
