@@ -38,7 +38,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.alerting_admin", "trackme_rest_api_alerting_admin.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -143,7 +146,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -416,7 +419,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
         )
         try:
             response = requests.post(
-                record_url, headers=header, data=kwargs, verify=False, timeout=300
+                record_url, headers=header, data=kwargs, verify=False, timeout=600
             )
             logger.info(
                 f'tenant_id="{tenant_id}", action="success", alert_name="{alert_name}"'
@@ -617,7 +620,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
