@@ -32,7 +32,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.alerting_user", "trackme_rest_api_alerting_user.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -110,7 +113,7 @@ class TrackMeHandlerAlertingReadOps_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
