@@ -28,7 +28,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_blocklist_user", "trackme_rest_api_splk_blocklist_user.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 import trackme_rest_handler
@@ -43,9 +46,9 @@ from trackme_libs_decisionmaker import convert_epoch_to_datetime
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkBlocklist_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkBlocklistRead_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkBlocklist_v2, self).__init__(
+        super(TrackMeHandlerSplkBlocklistRead_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -126,7 +129,7 @@ class TrackMeHandlerSplkBlocklist_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
