@@ -35,7 +35,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_cim_admin", "trackme_rest_api_splk_cim_admin.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -66,9 +69,9 @@ from trackme_libs_croniter import validate_cron_schedule
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkCimTracking_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkCimTrackingAdmin_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkCimTracking_v2, self).__init__(
+        super(TrackMeHandlerSplkCimTrackingAdmin_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -283,7 +286,7 @@ class TrackMeHandlerSplkCimTracking_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=300,
+                timeout=600,
             )
 
             # set loglevel
@@ -898,7 +901,7 @@ class TrackMeHandlerSplkCimTracking_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1328,7 +1331,7 @@ class TrackMeHandlerSplkCimTracking_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
