@@ -30,7 +30,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dhm_power", "trackme_rest_api_splk_dhm_power.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 import trackme_rest_handler
@@ -63,9 +66,9 @@ from trackme_libs_bulk_edit import post_bulk_edit, generic_batch_update
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDhm_v2, self).__init__(
+        super(TrackMeHandlerSplkDhmWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -120,7 +123,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -234,7 +237,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -347,7 +350,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -475,7 +478,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -613,7 +616,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
                 try:
                     future_tolerance = resp_dict["future_tolerance"]
                 except Exception as e:
-                    future_tolerance = "system"
+                    future_tolerance = None
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -658,7 +661,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -795,7 +798,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -911,7 +914,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1042,7 +1045,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1325,7 +1328,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1553,7 +1556,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1780,7 +1783,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
