@@ -29,7 +29,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dhm_user", "trackme_rest_api_splk_dhm_user.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 import trackme_rest_handler
@@ -50,9 +53,9 @@ from trackme_libs_utils import remove_leading_spaces
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDhm_v2, self).__init__(
+        super(TrackMeHandlerSplkDhmRead_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -148,7 +151,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -415,7 +418,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=300,
+                timeout=600,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -516,7 +519,7 @@ class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
