@@ -32,7 +32,10 @@ logger = setup_logger(
     "trackme.rest.splk_identity_cards_power",
     "trackme_rest_api_splk_identity_cards_power.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -45,9 +48,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkIdentityCardsWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkIdentityCards_v2, self).__init__(
+        super(TrackMeHandlerSplkIdentityCardsWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -139,7 +142,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -354,7 +357,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -594,7 +597,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
