@@ -32,7 +32,10 @@ logger = setup_logger(
     "trackme.rest.splk_identity_cards_user",
     "trackme_rest_api_splk_identity_cards_user.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -45,9 +48,9 @@ from trackme_libs import trackme_getloglevel
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkIdentityCardsRead_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkIdentityCards_v2, self).__init__(
+        super(TrackMeHandlerSplkIdentityCardsRead_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -112,7 +115,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -192,7 +195,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -297,7 +300,7 @@ class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
