@@ -34,7 +34,10 @@ logger = setup_logger(
     "trackme.rest.splk_priority_policies_power",
     "trackme_rest_api_splk_priority_policies_power.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -47,9 +50,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event, get_kv_collec
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkPriorityPolicies_v2, self).__init__(
+        super(TrackMeHandlerSplkPriorityPoliciesWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -239,7 +242,7 @@ class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -484,7 +487,7 @@ class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -803,7 +806,7 @@ class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1159,7 +1162,7 @@ class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1386,7 +1389,7 @@ class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
