@@ -33,7 +33,10 @@ logger = setup_logger(
     "trackme.rest.splk_replica_trackers_user",
     "trackme_rest_api_splk_replica_trackers_user.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -46,9 +49,9 @@ from trackme_libs import trackme_getloglevel
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkReplicaTracker_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkReplicaTrackerRead_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkReplicaTracker_v2, self).__init__(
+        super(TrackMeHandlerSplkReplicaTrackerRead_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -109,7 +112,7 @@ class TrackMeHandlerSplkReplicaTracker_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
