@@ -34,7 +34,10 @@ logger = setup_logger(
     "trackme.rest.splk_sla_policies_power",
     "trackme_rest_api_splk_sla_policies_power.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -52,9 +55,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkSlaPolicies_v2, self).__init__(
+        super(TrackMeHandlerSplkSlaPoliciesWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -242,7 +245,7 @@ class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -530,7 +533,7 @@ class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -819,7 +822,7 @@ class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1203,7 +1206,7 @@ class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1448,7 +1451,7 @@ class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
