@@ -31,7 +31,10 @@ logger = setup_logger(
     "trackme.rest.splk_smart_status",
     "trackme_rest_api_splk_smart_status.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # TrackMe REST handler
@@ -139,7 +142,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -162,7 +165,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
                 },
                 data=json.dumps({"tenant_id": tenant_id}),
                 verify=False,
-                timeout=300,
+                timeout=600,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -688,7 +691,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -711,7 +714,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
                 },
                 data=json.dumps({"tenant_id": tenant_id}),
                 verify=False,
-                timeout=300,
+                timeout=600,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -1074,7 +1077,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1198,7 +1201,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1383,7 +1386,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1568,7 +1571,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1753,7 +1756,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
