@@ -34,7 +34,10 @@ logger = setup_logger(
     "trackme.rest.splk_tag_policies_power",
     "trackme_rest_api_splk_tag_policies_power.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -47,9 +50,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event, get_kv_collec
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkTagPolicies_v2, self).__init__(
+        super(TrackMeHandlerSplkTagPoliciesWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -213,7 +216,7 @@ class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -451,7 +454,7 @@ class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -733,7 +736,7 @@ class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1046,7 +1049,7 @@ class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1277,7 +1280,7 @@ class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
