@@ -35,7 +35,10 @@ logger = setup_logger(
     "trackme.rest.splk_wlk_admin",
     "trackme_rest_api_splk_wlk_admin.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -62,9 +65,9 @@ from trackme_libs_licensing import trackme_check_license
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkWlk_v2, self).__init__(
+        super(TrackMeHandlerSplkWlkAdmin_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -234,7 +237,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
 
             elif tracker_type == "splunkcloud_svc":
                 tracker_search = f"""\
-                    ((index=_cmc_summary OR index=summary) source="splunk-svc-consumer") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint}
+                    ((index=_cmc_summary OR index=summary) source="splunk-svc-search-attribution") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint}
                     | fields _time svc_usage svc_consumer svc_consumption_score search_type search_app search_label search_user search_head_names unified_sid process_type
                     | fillnull value="" svc_consumer process_type search_provenances search_type search_app search_label search_user unified_sid search_modes labels search_head_names usage_source
                     | stats max(svc_usage) as svc_usage by _time svc_consumer search_type search_app search_label search_user search_head_names unified_sid process_type
@@ -482,7 +485,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=300,
+                timeout=600,
             )
 
             # set loglevel
@@ -741,7 +744,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
 
             elif tracker_type == "splunkcloud_svc":
                 tracker_search = f"""\
-                    ((index=_cmc_summary OR index=summary) source="splunk-svc-consumer") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint} _index_earliest="{index_earliest_time}" _index_latest="{index_latest_time}"
+                    ((index=_cmc_summary OR index=summary) source="splunk-svc-search-attribution") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint} _index_earliest="{index_earliest_time}" _index_latest="{index_latest_time}"
                     | fields _time svc_usage svc_consumer svc_consumption_score search_type search_app search_label search_user search_head_names unified_sid process_type
                     | fillnull value="" svc_consumer process_type search_provenances search_type search_app search_label search_user unified_sid search_modes labels search_head_names usage_source
                     | stats max(svc_usage) as svc_usage by _time svc_consumer search_type search_app search_label search_user search_head_names unified_sid process_type
@@ -1384,7 +1387,7 @@ class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=300,
+                timeout=600,
             )
 
             # set loglevel
