@@ -19,6 +19,7 @@ import os
 import random
 import sys
 import time
+import concurrent.futures
 from logging.handlers import RotatingFileHandler
 
 # Third-party imports
@@ -67,6 +68,19 @@ from splunklib.searchcommands import (
 # Import trackme libs
 from trackme_libs import trackme_reqinfo
 
+# Import trackme libs
+from trackme_libs_utils import get_uuid
+
+# import TrackMe get data libs
+from trackme_libs_get_data import (
+    search_kv_collection_restmode,
+    search_kv_collection_searchmode,
+    search_kv_collection_sdkmode,
+)
+
+# Import trackMe kvstore batch libs
+from trackme_libs_kvstore_batch import batch_update_worker
+
 
 @Configuration(distributed=False)
 class SplkOutliersSetRules(StreamingCommand):
@@ -87,36 +101,6 @@ class SplkOutliersSetRules(StreamingCommand):
         validate=validators.Match("component", r"^(?:dsm|dhm|flx|fqm|wlk)$"),
     )
 
-    def get_collection_records(self, collection, collection_name):
-        # get all records
-        get_collection_start = time.time()
-        collection_records = []
-        collection_records_keys = set()
-
-        end = False
-        skip_tracker = 0
-        while end == False:
-            process_collection_records = collection.data.query(skip=skip_tracker)
-            if len(process_collection_records) != 0:
-                for item in process_collection_records:
-                    if item.get("_key") not in collection_records_keys:
-                        collection_records.append(item)
-                        collection_records_keys.add(item.get("_key"))
-                skip_tracker += 5000
-            else:
-                end = True
-
-        # turn this into a dict
-        collection_data_dict = {}
-        for record in collection_records:
-            key = record["object"]
-            collection_data_dict[key] = record
-
-        logging.info(
-            f'context="perf", get data collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", tenant_id="{self.tenant_id}", component="{self.component}"'
-        )
-
-        return collection_records, collection_records_keys, collection_data_dict
 
     def stream(self, records):
         # Start performance counter
@@ -128,6 +112,14 @@ class SplkOutliersSetRules(StreamingCommand):
         )
         log.setLevel(reqinfo["logging_level"])
 
+        # Max multi thread workers
+        max_multi_thread_workers = int(
+            reqinfo["trackme_conf"]["trackme_general"]["max_multi_thread_workers"]
+        )
+
+        # set instance_id
+        self.instance_id = get_uuid()
+
         # Get app level config
         splk_outliers_detection = reqinfo["trackme_conf"]["splk_outliers_detection"]
 
@@ -204,6 +196,12 @@ class SplkOutliersSetRules(StreamingCommand):
         # Outliers rules collection
         #
 
+        # set task
+        #
+        task_start = time.time()
+        task_instance_id = get_uuid()
+        task_name = "get_outliers_rules_collection_records"
+
         collection_outliers_name = (
             f"kv_trackme_{self.component}_outliers_entity_rules_tenant_{self.tenant_id}"
         )
@@ -214,12 +212,34 @@ class SplkOutliersSetRules(StreamingCommand):
             collection_outliers_records,
             collection_outliers_records_keys,
             collection_outliers_dict,
-        ) = self.get_collection_records(collection_outliers, collection_outliers_name)
+            last_page,
+        ) = search_kv_collection_sdkmode(
+            logging,
+            self.service,
+            collection_outliers_name,
+            page=1,
+            page_count=0,
+            orderby="keyid",
+        )
+
+        # end task
+        #
+        task_end = time.time()
+        task_run_time = round((task_end - task_start), 3)
+        logging.info(
+            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
+        )
 
         #
         # Data collection
         #
 
+        # set task
+        #
+        task_start = time.time()
+        task_instance_id = get_uuid()
+        task_name = "get_data_collection_records"
+
         collection_data_name = f"kv_trackme_{self.component}_tenant_{self.tenant_id}"
         collection_data = self.service.kvstore[collection_data_name]
 
@@ -228,11 +248,33 @@ class SplkOutliersSetRules(StreamingCommand):
             collection_data_records,
             collection_data_records_keys,
             collection_data_dict,
-        ) = self.get_collection_records(collection_data, collection_data_name)
+            last_page,
+        ) = search_kv_collection_sdkmode(
+            logging,
+            self.service,
+            collection_data_name,
+            page=1,
+            page_count=0,
+            orderby="keyid",
+        )
+
+        # end task
+        #
+        task_end = time.time()
+        task_run_time = round((task_end - task_start), 3)
+        logging.info(
+            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
+        )
 
         # final records to be batched processed in the KVstore
         final_records = []
 
+        # set task
+        #
+        task_start = time.time()
+        task_instance_id = get_uuid()
+        task_name = "process_records"
+
         # Loop in the results
         for record in records:
             # check if outliers models are defined already
@@ -263,7 +305,7 @@ class SplkOutliersSetRules(StreamingCommand):
                             check_for_creation = True
                         except Exception as e:
                             logging.info(
-                                f'object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
+                                f'instance_id={self.instance_id}, object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
                             )
 
             # for other components, we create models if these are not defined yet
@@ -364,7 +406,7 @@ class SplkOutliersSetRules(StreamingCommand):
 
                         final_records.append(new_kvrecord)
                         logging.info(
-                            f'tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
+                            f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
                         )
 
                     # for splk-flx/splk-fqm/splk-wlk
@@ -386,7 +428,7 @@ class SplkOutliersSetRules(StreamingCommand):
                                 record_definition_is_valid = True
                             except Exception as e:
                                 logging.info(
-                                    f'object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
+                                    f'instance_id={self.instance_id}, object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
                                 )
 
                         # if record_outliers_metrics is an empty dict, record_definition_is_valid must be False
@@ -718,12 +760,12 @@ class SplkOutliersSetRules(StreamingCommand):
 
                             final_records.append(new_kvrecord)
                             logging.info(
-                                f'tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
+                                f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
                             )
 
                 except Exception as e:
                     logging.error(
-                        f'tenant_id="{self.tenant_id}", Outliers rules creation failed with exception="{str(e)}"'
+                        f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules creation failed with exception="{str(e)}"'
                     )
 
             # yield original record
@@ -735,28 +777,42 @@ class SplkOutliersSetRules(StreamingCommand):
 
             yield yield_record
 
-        # batch update/insert
-        if len(final_records) > 0:
-            batch_update_collection_start = time.time()
+        # end task
+        #
+        task_end = time.time()
+        task_run_time = round((task_end - task_start), 3)
+        logging.info(
+            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
+        )
 
-            # process by chunk
-            chunks = [
-                final_records[i : i + 500] for i in range(0, len(final_records), 500)
-            ]
-            for chunk in chunks:
-                try:
-                    collection_outliers.data.batch_save(*chunk)
-                except Exception as e:
-                    logging.error(f'KVstore batch failed with exception="{str(e)}"')
+        # set task
+        #
+        task_start = time.time()
+        task_instance_id = get_uuid()
+        task_name = "kvstore_batch_update"
 
-            # perf counter for the batch operation
-            logging.info(
-                f'context="perf", batch KVstore update terminated, no_records="{len(final_records)}", run_time="{round((time.time() - batch_update_collection_start), 3)}", tenant_id="{self.tenant_id}", component="{self.component}"'
-            )
+        # Execute batch update synchronously
+        batch_update_worker(
+            collection_outliers_name,
+            collection_outliers,
+            final_records,
+            self.instance_id,
+            task_instance_id,
+            task_name=task_name,
+            max_multi_thread_workers=max_multi_thread_workers,
+        )
+
+        # end task
+        #
+        task_end = time.time()
+        task_run_time = round((task_end - task_start), 3)
+        logging.info(
+            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated. no_records="{len(final_records)}", collection="{collection_outliers_name}"'
+        )
 
         # Log the run time
         logging.info(
-            f'trackmesplkoutlierssetrules has terminated, tenant_id="{self.tenant_id}", component="{self.component}", run_time={round(time.time() - start, 3)}'
+            f'instance_id={self.instance_id}, trackmesplkoutlierssetrules has terminated, tenant_id="{self.tenant_id}", component="{self.component}", run_time={round(time.time() - start, 3)}'
         )
 
 
