@@ -85,14 +85,14 @@ def trackme_audits_callback(
     url = f"{splunkd_uri}/services/trackme/v2/audit/audit_events_v2"
     data = {
         "tenant_id": f"{tenant_id}",
-        "audit_events": f"{audit_events}",
+        "audit_events": audit_events,
     }
 
     # Proceed
     logging.info(f'calling endpoint with data="{json.dumps(data)}"')
     try:
         response = requests.post(
-            url, headers=header, data=json.dumps(data), verify=False, timeout=300
+            url, headers=header, data=json.dumps(data), verify=False, timeout=600
         )
         if response.ok:
             logging.debug(f'Success audit event, data="{response}"')
@@ -140,6 +140,26 @@ def trackme_audit_gen(audit_index, audit_event_list):
             audit_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             audit_logger.propagate = False
+        else:
+            # Find the RotatingFileHandler among existing handlers
+            filehandler = None
+            for handler in audit_logger.handlers:
+                if isinstance(handler, RotatingFileHandler):
+                    filehandler = handler
+                    break
+            
+            # If no RotatingFileHandler found, create one
+            if filehandler is None:
+                filehandler = RotatingFileHandler(
+                    f"{splunkhome}/var/log/splunk/trackme_audit_events.log",
+                    mode="a",
+                    maxBytes=100000000,
+                    backupCount=1,
+                )
+                formatter = JSONFormatter(timestamp=time.time())
+                logging.Formatter.converter = time.gmtime
+                filehandler.setFormatter(formatter)
+                audit_logger.addHandler(filehandler)
 
         for audit_event in audit_event_list:
             # calculate the event_id as the sha-256 sum of the audit_event
@@ -199,6 +219,26 @@ def trackme_handler_events_gen(
             handler_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             handler_logger.propagate = False
+        else:
+            # Find the RotatingFileHandler among existing handlers
+            filehandler = None
+            for handler in handler_logger.handlers:
+                if isinstance(handler, RotatingFileHandler):
+                    filehandler = handler
+                    break
+            
+            # If no RotatingFileHandler found, create one
+            if filehandler is None:
+                filehandler = RotatingFileHandler(
+                    f"{splunkhome}/var/log/splunk/trackme_handler_events.log",
+                    mode="a",
+                    maxBytes=100000000,
+                    backupCount=1,
+                )
+                formatter = JSONFormatter(timestamp=time.time())
+                logging.Formatter.converter = time.gmtime
+                filehandler.setFormatter(formatter)
+                handler_logger.addHandler(filehandler)
 
         for handler_event in handler_event_list:
             # calculate the event_id as the sha-256 sum of the audit_event
